/**************************************************************************
 FILE:
	osi_trace_user.h

 DESCRIPTION:
	Format of SNIT tracing definitions being passed out of the kernel
	(for OSI protocols).

	@(#)osi_trace_user.h 1.4 91/01/11
 **************************************************************************/

#ifndef __osi_trace_user__
#define __osi_trace_user__

/* Matches an ethernet header. */
struct ot_zero {
	u_char 		zero[14];	/* all zero's */
};

struct ot_header {
	u_char		provider;
	u_char		type;
	u_short 	length
};

#define SET_OTH_PROVIDER(oth, provider) ((oth)->provider = (u_char)provider)
#define GET_OTH_PROVIDER(oth) 		(trace_provider_t)((oth)->provider)
#define SET_OTH_TYPE(oth, type) 	((oth)->type = (u_char)type)
#define GET_OTH_TYPE(oth) 		(trace_type_t)((oth)->type)

struct ot_data {
	struct ot_header	header;
	u_short			pci_len;
	u_short			data_len;
	u_short		 	direction;
	u_short			pad;	/* longword allign data in user space 
					 * (KERNEL not defined) 
					 */
	/* Data follows here */
	u_char			data[4];	/* placeholder */
};

#define SET_OTH_DIRECTION(oth, direction)\
 	((oth)->direction = (u_short)direction)
#define GET_OTH_DIRECTION(oth) 		(direction_t)((oth)->direction)

#define PARAM_LEN	6	/* For TP #0 is local ref and #1 is remote 
				 * ref */

struct ot_state {
	struct ot_header	header;
	int	state;
	int	event;
	char	action_routine[5*4];	
        u_int	params[PARAM_LEN];
	/* plus data */
};

struct ot_event {
	struct ot_header	header;
	int	event;
        u_int	params[PARAM_LEN];
	/* plus data */
};

/* Only for the SOCK_EVENT interfaces */
struct ot_eventreq {
	struct ot_header	header;
	int	req;	/* PRU_ */
	int	namlen;	/* nam is the first namlen octets of data */
	int	mlen;	/* m is octet namlen+1 .. namlen+mlen of data */
};

struct ot_queue {
	struct ot_header	header;
	char	action_routine[5*4];	
        u_int	params[PARAM_LEN];	/* For TP #2 is number of PDUs on
					   send queue, #3 recv queue, #4
					   recv expedited queue */
	u_int	queues[1];		/* place holder */
};

struct ot_timer {
	struct ot_header	header;
	char	action_routine[5*4];	
        u_int	params[PARAM_LEN];
};

/* For HEX and STRING info */
struct ot_unspec {
	struct ot_header	header;
	u_char			data[1];	/* placeholder */
};

#endif
